@@ -4,7 +4,7 @@ import tensorflow as tf
 from gpflow.kernels import Kernel, MultioutputKernel
 from gpflow.covariances import Kuu
 
-from ..conditionals.utils import create_linear_operator_pd
+from ..conditionals.utils import to_positive_definite_linop
 from ..inducing_variables.base import InducingPointsExtended
 
 
@@ -19,7 +19,7 @@ def _Kuu_linop(inducing_variable, kernel, *, jitter=0.0):
 
     Kzz = kernel(inducing_variable.Z)
     Kzz += jitter * tf.eye(inducing_variable.num_inducing, dtype=Kzz.dtype)
-    return create_linear_operator_pd(Kzz)
+    return to_positive_definite_linop(Kzz)
 
 
 @Kuu.register(InducingPointsExtended, MultioutputKernel)
