@@ -28,3 +28,10 @@ def gramian(a, b=None, diag: bool = True):
         b = a
     return tf.reduce_sum(a * b, axis=-2) if diag \
         else tf.linalg.matmul(a, b, adjoint_a=True)
+
+
+def triangular_solvevec(matrix, rhs, lower=True, adjoint=False, name=None):
+    x = tf.linalg.triangular_solve(
+        matrix, tf.expand_dims(rhs, axis=-1), lower, adjoint, name
+    )
+    return tf.squeeze(x, axis=-1)
