@@ -6,7 +6,7 @@ import numpy as np
 import tensorflow as tf
 import tensorflow_probability as tfp
 
-from gptk.conditionals.utils import adjoint_scale_mvn
+from gptk.conditionals.utils import scale_mvn
 
 tfd = tfp.distributions
 
@@ -16,10 +16,9 @@ def adjoint(n_inducing, n_test, random_state):
     return random_state.randn(n_inducing, n_test)  # [M, N]
 
 
-@pytest.mark.parametrize("diag_cov", [False, True])
 def test_adjoint_scale_mvn(adjoint, q_loc, q_scale_linop, diag_cov):
 
-    loc_new, cov_new = adjoint_scale_mvn(adjoint, q_loc, q_scale_linop, diag_cov)
+    loc_new, cov_new = scale_mvn(adjoint, q_loc, q_scale_linop, diag_cov)
 
     linop_adjoint = tf.linalg.LinearOperatorFullMatrix(adjoint)
     # linop = tf.linalg.LinearOperatorAdjoint(linop_adjoint)
